# Example README

This is a python package built using C++ code as the source to enable using C++ code in Python. 


## Installation

Install with pip. Run the following in cmd line:
```
  py -m pip install Tan_Soon_Seng
```
Alternatively on MacOS/Linux:
```
  python3 -m pip install Tan_Soon_Seng
```

## Acknowledgements

 - [Pybind11 Library](https://github.com/pybind/pybind11)
 - [Python Example by pybind11](https://github.com/pybind/python_example)

